package com.spider.quartz.mapper;

import com.spider.quartz.domain.ExcelDownloadLog;

import java.util.List;

/**
 * 美国、欧盟召回数据excel 下载记录Mapper接口
 * 
 * @author ruoyi
 * @date 2025-11-27
 */
public interface ExcelDownloadLogMapper 
{
    /**
     * 查询美国、欧盟召回数据excel 下载记录
     * 
     * @param id 美国、欧盟召回数据excel 下载记录主键
     * @return 美国、欧盟召回数据excel 下载记录
     */
    public ExcelDownloadLog selectExcelDownloadLogById(Long id);

    /**
     * 查询美国、欧盟召回数据excel 下载记录列表
     * 
     * @param excelDownloadLog 美国、欧盟召回数据excel 下载记录
     * @return 美国、欧盟召回数据excel 下载记录集合
     */
    public List<ExcelDownloadLog> selectExcelDownloadLogList(ExcelDownloadLog excelDownloadLog);

    /**
     * 新增美国、欧盟召回数据excel 下载记录
     * 
     * @param excelDownloadLog 美国、欧盟召回数据excel 下载记录
     * @return 结果
     */
    public int insertExcelDownloadLog(ExcelDownloadLog excelDownloadLog);

    /**
     * 修改美国、欧盟召回数据excel 下载记录
     * 
     * @param excelDownloadLog 美国、欧盟召回数据excel 下载记录
     * @return 结果
     */
    public int updateExcelDownloadLog(ExcelDownloadLog excelDownloadLog);

    /**
     * 删除美国、欧盟召回数据excel 下载记录
     * 
     * @param id 美国、欧盟召回数据excel 下载记录主键
     * @return 结果
     */
    public int deleteExcelDownloadLogById(Long id);

    /**
     * 批量删除美国、欧盟召回数据excel 下载记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteExcelDownloadLogByIds(Long[] ids);
}
